import os
import requests
from libbananadm import vault
from libbananadm import policies


def init(args):
    client = vault.get_vault_client(args)
    monitor_policy_name = 'banana-monitor'
    client.sys.create_or_update_policy(
        name=monitor_policy_name,
        policy=policies.generate_monitor_policy(args),
    )
    print('created policy {}'.format(monitor_policy_name))

    client.sys.enable_auth_method(
        method_type='cert',
        path='{}/cert'.format(args.root_path),
    )
    print('enabled cert auth method on path {}/cert'.format(args.root_path))


def reconfigure(args):
    client = vault.get_vault_client(args)
    token = client.create_token(
        policies=['banana-monitor'],
        lease='1h',
    )

    res = requests.post(
        args.monitor_addr + '/reconfigure',
        data='{}\n{}'.format(
            os.getenv('VAULT_ADDR'),
            token['auth']['client_token'],
        ),
        verify=not args.skip_tls_verify,
    )
    if res.status_code >= 400:
        print(res.json())

    print('successfully reloaded nginx trust configuration')



import os
from libbananadm import vault


def create_agent(args):
    print('generating temporary token to allow new agent(s) to register')
    client = vault.get_vault_client(args)
    token = client.create_token(
        policies=['{}-agent-creation'.format(args.client)],
        lease='1h',
    )

    print('success! join your new agent(s) using:\n')
    print(
        'bananactl {} --vault-addr={} init {} {} <agent name>'
        .format(
            '--skip-tls-verify' if args.skip_tls_verify else '',
            os.getenv('VAULT_ADDR'),
            token['auth']['client_token'],
            args.client,
        )
    )



import os
from libbananadm import input
from libbananadm import vault


def promt_s3_secret_values():
    return {
        'AWS_ACCESS_KEY_ID': input.prompt(
            'AWS_ACCESS_KEY_ID', os.getenv('AWS_ACCESS_KEY_ID'),
        ),
        'AWS_SECRET_ACCESS_KEY': input.prompt(
            'AWS_SECRET_ACCESS_KEY', os.getenv('AWS_SECRET_ACCESS_KEY'),
        ),
    }


def prompt_secret_values(type):
    return {
        's3': promt_s3_secret_values,
    }[type]()


def create_backend_secret(args, values):
    client = vault.get_vault_client(args)
    secret_path = 'backends/{}'.format(args.name)
    mount_point = '{}/{}/secrets'.format(args.root_path, args.client)
    client.secrets.kv.v2.create_or_update_secret(
        path=secret_path,
        mount_point=mount_point,
        secret=values,
    )

    print(
        'successfully saved secret {} in KV engine {}'
        .format(secret_path, mount_point)
    )
